==> mariadb_11.4.7.orig.tar.gz: mariadb-11.4.7/storage/columnstore/columnstore/utils/regr/corr.h <==
/* Copyright (C) 2017 MariaDB Corporation

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

/***********************************************************************
 *   $Id$
 *
 *   corr.h
 ***********************************************************************/

/**
 * Columnstore interface for for the corr function
 *
 *
 *    CREATE AGGREGATE FUNCTION corr returns REAL soname 'libregr_mysql.so';
 *
 */
#pragma once

#include <cstdlib>
#include <string>
#include <vector>
#include <tr1/unordered_map>

#include "mcsv1_udaf.h"
#include "calpontsystemcatalog.h"
#include "windowfunctioncolumn.h"

#define EXPORT

namespace mcsv1sdk
{
// Return the corr value of the dataset

class corr : public mcsv1_UDAF
{
 public:
  // Defaults OK
  corr() : mcsv1_UDAF(){};
  virtual ~corr(){};

  virtual ReturnCode init(mcsv1Context* context, ColumnDatum* colTypes);

  virtual ReturnCode reset(mcsv1Context* context);

  virtual ReturnCode nextValue(mcsv1Context* context, ColumnDatum* valsIn);

  virtual ReturnCode subEvaluate(mcsv1Context* context, const UserData* valIn);

  virtual ReturnCode evaluate(mcsv1Context* context, static_any::any& valOut);

  virtual ReturnCode dropValue(mcsv1Context* context, ColumnDatum* valsDropped);

 protected:
};

};  // namespace mcsv1sdk

#undef EXPORT

==> mariadb_11.8.3.orig.tar.gz: mariadb-11.8.3/storage/columnstore/columnstore/utils/regr/corr.h <==
/* Copyright (C) 2017 MariaDB Corporation

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; version 2 of
   the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA. */

/***********************************************************************
 *   $Id$
 *
 *   corr.h
 ***********************************************************************/

/**
 * Columnstore interface for for the corr function
 *
 *
 *    CREATE AGGREGATE FUNCTION corr returns REAL soname 'libregr_mysql.so';
 *
 */
#pragma once

#include <cstdlib>
#include <string>
#include <vector>
#include <tr1/unordered_map>

#include "mcsv1_udaf.h"
#include "calpontsystemcatalog.h"
#include "windowfunctioncolumn.h"

#define EXPORT

namespace mcsv1sdk
{
// Return the corr value of the dataset

class corr : public mcsv1_UDAF
{
 public:
  // Defaults OK
  corr() : mcsv1_UDAF(){};
  ~corr() override = default;

  ReturnCode init(mcsv1Context* context, ColumnDatum* colTypes) override;

  ReturnCode reset(mcsv1Context* context) override;

  ReturnCode nextValue(mcsv1Context* context, ColumnDatum* valsIn) override;

  ReturnCode subEvaluate(mcsv1Context* context, const UserData* valIn) override;

  ReturnCode evaluate(mcsv1Context* context, static_any::any& valOut) override;

  ReturnCode dropValue(mcsv1Context* context, ColumnDatum* valsDropped) override;

 protected:
};

};  // namespace mcsv1sdk

#undef EXPORT
